pub struct TryCatch<This, J>{ /* private fields */ }Trait Implementations
sourceimpl<This, J> JvmOp for TryCatch<This, J>
impl<This, J> JvmOp for TryCatch<This, J>
type Output<'jvm> = Result<<This as JvmOp>::Output<'jvm>, Local<'jvm, J>>
sourcefn do_jni<'jvm>(
self,
jvm: &mut Jvm<'jvm>,
) -> LocalResult<'jvm, Self::Output<'jvm>>
fn do_jni<'jvm>( self, jvm: &mut Jvm<'jvm>, ) -> LocalResult<'jvm, Self::Output<'jvm>>
Internal method
fn assert_not_null<T>(self) -> NotNull<Self>
sourcefn upcast<To>(self) -> AsUpcast<Self, To>
fn upcast<To>(self) -> AsUpcast<Self, To>
Most duchess-wrapped Java objects will automatically be able to call all
methods defined on any of its super classes or interfaces it implements,
but this can be used to “force” the output of the operation to be typed
as an explicit super type
To.fn catch<J>(self) -> TryCatch<Self, J>where
J: Upcast<Throwable>,
sourcefn execute<R>(self) -> Result<R>
fn execute<R>(self) -> Result<R>
Execute on the JVM, starting a JVM instance if necessary. Read more
sourcefn execute_with<'jvm, R>(self, jvm: &mut Jvm<'jvm>) -> LocalResult<'jvm, R>
fn execute_with<'jvm, R>(self, jvm: &mut Jvm<'jvm>) -> LocalResult<'jvm, R>
Internal method
impl<This, J> Copy for TryCatch<This, J>